@@ -5,7 +5,7 @@
 #' @param custom_var_names A vector of custom variable names used in presentation that match the order of the \code{form} object passed to \code{fergm}.  If not provided, defaults to names inherited by \code{fergm.fit}.
 #' @return This function returns a matrix summarizing the posterior distribution, including variable names, posterior means, and 95% credible intervals.
 #' @keywords FERGM interpret summary
-#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2017. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}.
+#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2018. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}. (26)1:3-19.
 #' @references Stan Development Team (2016). RStan: the R interface to Stan. R package version 2.14.1. \url{http://mc-stan.org/}.
 #' @examples
 #' # The fergm.fit$stan.fit object is of class stanfit.
@@ -40,7 +40,7 @@ clean_summary <- function(fergm.fit = NULL, custom_var_names = NULL){
   if(!is.null(custom_var_names)){
     rownames(fergm_df) <- custom_var_names
   } else {
-    rownames(fergm_df) <- stringr::str_replace_all(string = unlist(strsplit(form, "[+]")), pattern=" ", repl="")
+    rownames(fergm_df) <- colnames(fergm.fit$stan.dta$x)
   }
   return(fergm_df)
 }
