@@ -4,7 +4,7 @@
 #' @param fergm.fit A model object returned by the \code{fergm} function.  Must be specified.
 #' @param custom_var_names A vector of custom variable names used in presentation that match the order of the \code{form} object passed to \code{fergm}.  If not provided, defaults to names inherited by \code{fergm.fit}.
 #' @return This prints a list of posterior density plots produced using ggplot2.
-#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2017. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}.
+#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2018. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}. (26)1:3-19.
 #' @references Stan Development Team (2016). RStan: the R interface to Stan. R package version 2.14.1. \url{http://mc-stan.org/}.
 #' @keywords FERGM interpret summary
 #' @examples
@@ -33,8 +33,7 @@ coef_posterior_density <- function(fergm.fit = NULL, custom_var_names = NULL){
   its <- rstan::extract(fergm.fit$stan.fit)$beta
 
   if(is.null(custom_var_names)){
-    custom_var_names <- fergm.fit$form
-    custom_var_names <- stringr::str_replace_all(string = unlist(strsplit(custom_var_names, "[+]")), pattern=" ", repl="")
+    custom_var_names <- colnames(fergm.fit$stan.dta$x)
   }
 
   plot_list <- list()
