@@ -6,7 +6,7 @@
 #' @param seed An integer that sets the seed for the random number generator to assist in replication.  Defaults to 12345.
 #' @param replications The number of networks to be simulated to assess predictions. Defaults to 500.
 #' @keywords Fit GOF Prediction.
-#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2017. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}.
+#' @references Box-Steffensmeier, Janet M., Dino P. Christenson, and Jason W. Morgan. 2018. ``Modeling Unobserved Heterogeneity in Social Networks with the Frailty Exponential Random Graph Model." \emph{Political Analysis}. (26)1:3-19.
 #' @references Stan Development Team (2016). RStan: the R interface to Stan. R package version 2.14.1. \url{http://mc-stan.org/}.
 #' @return The compare_predictions function returns a matrix reflecting the number of correctly predicted ties for the ERGM and FERGM for each network simulated.
 #' @examples
@@ -31,12 +31,13 @@
 
 compare_predictions <- function(ergm.fit = NULL, fergm.fit = NULL, seed = 12345, replications = 500){
   lt <- function(m) { m[lower.tri(m)] }
+  n_dyads <- choose(ergm.fit$network$gal$n, 2)
 
   ergm.pred <- function()
   {
     flo.truth <- lt(as.matrix(ergm.fit$network))
     sim.pred <- lt(as.matrix(simulate.ergm(ergm.fit)))
-    sum(flo.truth == sim.pred) / 630
+    sum(flo.truth == sim.pred) / n_dyads
   }
 
   pct_correct_ergm <- replicate(replications, ergm.pred())
@@ -48,7 +49,7 @@ compare_predictions <- function(ergm.fit = NULL, fergm.fit = NULL, seed = 12345,
   predictions <- extract(stan.fit, "predictions")$predictions
 
   pct_correct_fergm <- sapply(1:nrow(predictions),
-                              function(r) sum(truth == predictions[r,]) / 630)
+                              function(r) sum(truth == predictions[r,]) / n_dyads)
 
 
   correct_mat <- cbind(pct_correct_ergm, pct_correct_fergm)
